NAME
    BusyBox - The Swiss Army Knife of Embedded Linux

SYNTAX
     busybox <applet> [arguments...]  # or

     <applet> [arguments...]          # if symlinked

DESCRIPTION
    BusyBox combines tiny versions of many common UNIX utilities into a
    single small executable. It provides minimalist replacements for most of
    the utilities you usually find in GNU coreutils, util-linux, etc. The
    utilities in BusyBox generally have fewer options than their
    full-featured GNU cousins; however, the options that are included
    provide the expected functionality and behave very much like their GNU
    counterparts.

    BusyBox has been written with size-optimization and limited resources in
    mind. It is also extremely modular so you can easily include or exclude
    commands (or features) at compile time. This makes it easy to customize
    your embedded systems. To create a working system, just add /dev, /etc,
    and a Linux kernel. BusyBox provides a fairly complete POSIX environment
    for any small or embedded system.

    BusyBox is extremely configurable. This allows you to include only the
    components you need, thereby reducing binary size. Run 'make config' or
    'make menuconfig' to select the functionality that you wish to enable.
    Then run 'make' to compile BusyBox using your configuration.

    After the compile has finished, you should use 'make install' to install
    BusyBox. This will install the 'bin/busybox' binary, in the target
    directory specified by CONFIG_PREFIX. CONFIG_PREFIX can be set when
    configuring BusyBox, or you can specify an alternative location at
    install time (i.e., with a command line like 'make
    CONFIG_PREFIX=/tmp/foo install'). If you enabled any applet installation
    scheme (either as symlinks or hardlinks), these will also be installed
    in the location pointed to by CONFIG_PREFIX.

USAGE
    BusyBox is a multi-call binary. A multi-call binary is an executable
    program that performs the same job as more than one utility program.
    That means there is just a single BusyBox binary, but that single binary
    acts like a large number of utilities. This allows BusyBox to be smaller
    since all the built-in utility programs (we call them applets) can share
    code for many common operations.

    You can also invoke BusyBox by issuing a command as an argument on the
    command line. For example, entering

            /bin/busybox ls

    will also cause BusyBox to behave as 'ls'.

    Of course, adding '/bin/busybox' into every command would be painful. So
    most people will invoke BusyBox using links to the BusyBox binary.

    For example, entering

            ln -s /bin/busybox ls
            ./ls

    will cause BusyBox to behave as 'ls' (if the 'ls' command has been
    compiled into BusyBox). Generally speaking, you should never need to
    make all these links yourself, as the BusyBox build system will do this
    for you when you run the 'make install' command.

    If you invoke BusyBox with no arguments, it will provide you with a list
    of the applets that have been compiled into your BusyBox binary.

COMMON OPTIONS
    Most BusyBox applets support the --help argument to provide a terse
    runtime description of their behavior. If the
    CONFIG_FEATURE_VERBOSE_USAGE option has been enabled, more detailed
    usage information will also be available.

COMMANDS
    Currently available applets include:

            [, [[, ar, awk, base64, basename, bunzip2, bzcat, bzip2, cal, cat,
            catv, chat, chgrp, chmod, chown, chpasswd, chpst, chroot, chrt,
            cksum, clear, cmp, comm, cp, cpio, cryptpw, cut, date, dc, dd,
            devmem, df, diff, dirname, dnsd, dnsdomainname, dos2unix, du, echo,
            ed, egrep, env, envdir, envuidgid, expand, expr, fakeidentd, false,
            fgrep, find, fold, fsync, ftpd, ftpget, ftpput, fuser, getopt, grep,
            groups, gunzip, gzip, hd, head, hexdump, hostid, hostname, httpd,
            id, inetd, install, iostat, ipcalc, kill, killall, killall5, less,
            ln, logger, logname, logread, lpd, lpq, lpr, ls, lzcat, lzma, lzop,
            lzopcat, makemime, man, md5sum, mesg, microcom, mkdir, mkfifo,
            mknod, mkpasswd, mktemp, more, mpstat, mt, mv, nc, nice, nmeter,
            nohup, nslookup, od, patch, pgrep, pidof, pipe_progress, pkill,
            popmaildir, printenv, printf, ps, pscan, pstree, pwd, pwdx,
            readlink, realpath, reformime, renice, reset, resize, rm, rmdir,
            rpm, rpm2cpio, run-parts, runsv, runsvdir, sed, sendmail, seq,
            setsid, setuidgid, sha1sum, sha256sum, sha512sum, sleep, smemcap,
            softlimit, sort, split, start-stop-daemon, stat, strings, stty, sum,
            sv, svlogd, sync, sysctl, syslogd, tac, tail, tar, tcpsvd, tee,
            telnet, telnetd, test, tftp, tftpd, time, timeout, touch, tr, true,
            tty, ttysize, udpsvd, uname, uncompress, unexpand, uniq, unix2dos,
            unlzma, unlzop, unxz, unzip, usleep, uudecode, uuencode, vlock,
            volname, watch, wc, which, whoami, whois, xargs, xz, xzcat, yes,
            zcat

COMMAND DESCRIPTIONS
    ar  ar [-o] [-v] [-p] [-t] [-x] ARCHIVE FILES

        Extract or list FILES from an ar archive

                -o      Preserve original dates
                -p      Extract to stdout
                -t      List
                -x      Extract
                -v      Verbose

    awk awk [OPTIONS] [AWK_PROGRAM] [FILE]...

                -v VAR=VAL      Set variable
                -F SEP          Use SEP as field separator
                -f FILE         Read program from FILE

    base64
        base64 [-d] [FILE]

        Base64 encode or decode FILE to standard output -d Decode data

    basename
        basename FILE [SUFFIX]

        Strip directory path and .SUFFIX from FILE

    bunzip2
        bunzip2 [-cf] [FILE]...

        Decompress FILEs (or stdin)

                -c      Write to stdout
                -f      Force

    bzcat
        bzcat FILE

        Decompress to stdout

    bzip2
        bzip2 [OPTIONS] [FILE]...

        Compress FILEs (or stdin) with bzip2 algorithm

                -1..9   Compression level
                -d      Decompress
                -c      Write to stdout
                -f      Force

    cal cal [-jy] [[MONTH] YEAR]

        Display a calendar

                -j      Use julian dates
                -y      Display the entire year

    cat cat [FILE]...

        Concatenate FILEs and print them to stdout

    catv
        catv [-etv] [FILE]...

        Display nonprinting characters as ^x or M-x

                -e      End each line with $
                -t      Show tabs as ^I
                -v      Don't use ^x or M-x escapes

    chat
        chat EXPECT [SEND [EXPECT [SEND...]]]

        Useful for interacting with a modem connected to stdin/stdout. A
        script consists of one or more "expect-send" pairs of strings, each
        pair is a pair of arguments. Example: chat '' ATZ OK ATD123456
        CONNECT '' ogin: pppuser word: ppppass '~'

    chgrp
        chgrp [-RhLHPcvf]... GROUP FILE...

        Change the group membership of each FILE to GROUP

                -R      Recurse
                -h      Affect symlinks instead of symlink targets
                -L      Traverse all symlinks to directories
                -H      Traverse symlinks on command line only
                -P      Don't traverse symlinks (default)
                -c      List changed files
                -v      Verbose
                -f      Hide errors

    chmod
        chmod [-Rcvf] MODE[,MODE]... FILE...

        Each MODE is one or more of the letters ugoa, one of the symbols +-=
        and one or more of the letters rwxst

                -R      Recurse
                -c      List changed files
                -v      List all files
                -f      Hide errors

    chown
        chown [-RhLHPcvf]... OWNER[<.|:>[GROUP]] FILE...

        Change the owner and/or group of each FILE to OWNER and/or GROUP

                -R      Recurse
                -h      Affect symlinks instead of symlink targets
                -L      Traverse all symlinks to directories
                -H      Traverse symlinks on command line only
                -P      Don't traverse symlinks (default)
                -c      List changed files
                -v      List all files
                -f      Hide errors

    chpasswd
        chpasswd [--md5|--encrypted]

        Read user:password from stdin and update /etc/passwd

                -e,--encrypted  Supplied passwords are in encrypted form
                -m,--md5        Use MD5 encryption instead of DES

    chpst
        chpst [-vP012] [-u USER[:GRP]] [-U USER[:GRP]] [-e DIR] [-/ DIR] [-n
        NICE] [-m BYTES] [-d BYTES] [-o N] [-p N] [-f BYTES] [-c BYTES] PROG
        ARGS

        Change the process state, run PROG

                -u USER[:GRP]   Set uid and gid
                -U USER[:GRP]   Set $UID and $GID in environment
                -e DIR          Set environment variables as specified by files
                                in DIR: file=1st_line_of_file
                -/ DIR          Chroot to DIR
                -n NICE         Add NICE to nice value
                -m BYTES        Same as -d BYTES -s BYTES -l BYTES
                -d BYTES        Limit data segment
                -o N            Limit number of open files per process
                -p N            Limit number of processes per uid
                -f BYTES        Limit output file sizes
                -c BYTES        Limit core file size
                -v              Verbose
                -P              Create new process group
                -0              Close stdin
                -1              Close stdout
                -2              Close stderr

    chroot
        chroot NEWROOT [PROG ARGS]

        Run PROG with root directory set to NEWROOT

    chrt
        chrt [-prfom] [PRIO] [PID | PROG ARGS]

        Change scheduling priority and class for a process

                -p      Operate on PID
                -r      Set SCHED_RR class
                -f      Set SCHED_FIFO class
                -o      Set SCHED_OTHER class
                -m      Show min/max priorities

    cksum
        cksum FILES...

        Calculate the CRC32 checksums of FILES

    clear
        clear

        Clear screen

    cmp cmp [-l] [-s] FILE1 [FILE2 [SKIP1 [SKIP2]]]

        Compare FILE1 with FILE2 (or stdin)

                -l      Write the byte numbers (decimal) and values (octal)
                        for all differing bytes
                -s      Quiet

    comm
        comm [-123] FILE1 FILE2

        Compare FILE1 with FILE2

                -1      Suppress lines unique to FILE1
                -2      Suppress lines unique to FILE2
                -3      Suppress lines common to both files

    cp  cp [OPTIONS] SOURCE DEST

        Copy SOURCE to DEST, or multiple SOURCE(s) to DIRECTORY

                -a      Same as -dpR
                -R,-r   Recurse
                -d,-P   Preserve symlinks (default if -R)
                -L      Follow all symlinks
                -H      Follow symlinks on command line
                -p      Preserve file attributes if possible
                -f      Overwrite
                -i      Prompt before overwrite
                -l,-s   Create (sym)links

    cpio
        cpio [-dmvu] [-F FILE] [-H newc] [-tio] [-p DIR] [EXTR_FILE]...

        Extract or list files from a cpio archive, or create an archive (-o)
        or copy files (-p) using file list on stdin

        Main operation mode:

                -t      List
                -i      Extract EXTR_FILEs (or all)
                -o      Create (requires -H newc)
                -p DIR  Copy files to DIR
                -d      Make leading directories
                -m      Preserve mtime
                -v      Verbose
                -u      Overwrite
                -F FILE Input (-t,-i,-p) or output (-o) file
                -H newc Archive format

    cryptpw
        cryptpw [OPTIONS] [PASSWORD] [SALT]

        Crypt PASSWORD using crypt(3)

                -P,--password-fd=N      Read password from fd N
                -m,--method=TYPE        Encryption method
                -S,--salt=SALT

    cut cut [OPTIONS] [FILE]...

        Print selected fields from each input FILE to stdout

                -b LIST Output only bytes from LIST
                -c LIST Output only characters from LIST
                -d CHAR Use CHAR instead of tab as the field delimiter
                -s      Output only the lines containing delimiter
                -f N    Print only these fields
                -n      Ignored

    date
        date [OPTIONS] [+FMT] [TIME]

        Display time (using +FMT), or set time

                [-s,--set] TIME Set time to TIME
                -u,--utc        Work in UTC (don't convert to local time)
                -R,--rfc-2822   Output RFC-2822 compliant date string
                -I[SPEC]        Output ISO-8601 compliant date string
                                SPEC='date' (default) for date only,
                                'hours', 'minutes', or 'seconds' for date and
                                time to the indicated precision
                -r,--reference FILE     Display last modification time of FILE
                -d,--date TIME  Display TIME, not 'now'
                -D FMT          Use FMT for -d TIME conversion

        Recognized TIME formats:

                hh:mm[:ss]
                [YYYY.]MM.DD-hh:mm[:ss]
                YYYY-MM-DD hh:mm[:ss]
                [[[[[YY]YY]MM]DD]hh]mm[.ss]

    dc  dc EXPRESSION...

        Tiny RPN calculator. Operations: +, add, -, sub, *, mul, /, div, %,
        mod, **, exp, and, or, not, eor, p - print top of the stack (without
        popping), f - print entire stack, o - pop the value and set output
        radix (must be 10, 16, 8 or 2). Examples: 'dc 2 2 add p' -> 4, 'dc 8
        8 * 2 2 + / p' -> 16

    dd  dd [if=FILE] [of=FILE] [ibs=N] [obs=N] [bs=N] [count=N] [skip=N]
        [seek=N] [conv=notrunc|noerror|sync|fsync]

        Copy a file with converting and formatting

                if=FILE         Read from FILE instead of stdin
                of=FILE         Write to FILE instead of stdout
                bs=N            Read and write N bytes at a time
                ibs=N           Read N bytes at a time
                obs=N           Write N bytes at a time
                count=N         Copy only N input blocks
                skip=N          Skip N input blocks
                seek=N          Skip N output blocks
                conv=notrunc    Don't truncate output file
                conv=noerror    Continue after read errors
                conv=sync       Pad blocks with zeros
                conv=fsync      Physically write data out before finishing

        Numbers may be suffixed by c (x1), w (x2), b (x512), kD (x1000), k
        (x1024), MD (x1000000), M (x1048576), GD (x1000000000) or G
        (x1073741824)

    devmem
        devmem ADDRESS [WIDTH [VALUE]]

        Read/write from physical address

                ADDRESS Address to act upon
                WIDTH   Width (8/16/...)
                VALUE   Data to be written

    df  df [-Pkmhai] [-B SIZE] [FILESYSTEM]...

        Print filesystem usage statistics

                -P      POSIX output format
                -k      1024-byte blocks (default)
                -m      1M-byte blocks
                -h      Human readable (e.g. 1K 243M 2G)
                -a      Show all filesystems
                -i      Inodes
                -B SIZE Blocksize

    diff
        diff [-abBdiNqrTstw] [-L LABEL] [-S FILE] [-U LINES] FILE1 FILE2

        Compare files line by line and output the differences between them.
        This implementation supports unified diffs only.

                -a      Treat all files as text
                -b      Ignore changes in the amount of whitespace
                -B      Ignore changes whose lines are all blank
                -d      Try hard to find a smaller set of changes
                -i      Ignore case differences
                -L      Use LABEL instead of the filename in the unified header
                -N      Treat absent files as empty
                -q      Output only whether files differ
                -r      Recurse
                -S      Start with FILE when comparing directories
                -T      Make tabs line up by prefixing a tab when necessary
                -s      Report when two files are the same
                -t      Expand tabs to spaces in output
                -U      Output LINES lines of context
                -w      Ignore all whitespace

    dirname
        dirname FILENAME

        Strip non-directory suffix from FILENAME

    dnsd
        dnsd [-dvs] [-c CONFFILE] [-t TTL_SEC] [-p PORT] [-i ADDR]

        Small static DNS server daemon

                -c FILE Config file
                -t SEC  TTL
                -p PORT Listen on PORT
                -i ADDR Listen on ADDR
                -d      Daemonize
                -v      Verbose
                -s      Send successful replies only. Use this if you want
                        to use /etc/resolv.conf with two nameserver lines:
                                nameserver DNSD_SERVER
                                nameserver NORMAL_DNS_SERVER

    dos2unix
        dos2unix [-ud] [FILE]

        Convert FILE in-place from DOS to Unix format. When no file is
        given, use stdin/stdout.

                -u      dos2unix
                -d      unix2dos

    du  du [-aHLdclsxhmk] [FILE]...

        Summarize disk space used for each FILE and/or directory. Disk space
        is printed in units of 512 bytes.

                -a      Show file sizes too
                -L      Follow all symlinks
                -H      Follow symlinks on command line
                -d N    Limit output to directories (and files with -a) of depth < N
                -c      Show grand total
                -l      Count sizes many times if hard linked
                -s      Display only a total for each argument
                -x      Skip directories on different filesystems
                -h      Sizes in human readable format (e.g., 1K 243M 2G )
                -m      Sizes in megabytes
                -k      Sizes in kilobytes

    echo
        echo [-neE] [ARG]...

        Print the specified ARGs to stdout

                -n      Suppress trailing newline
                -e      Interpret backslash escapes (i.e., \t=tab)
                -E      Don't interpret backslash escapes (default)

    ed  ed

    env env [-iu] [-] [name=value]... [PROG ARGS]

        Print the current environment or run PROG after setting up the
        specified environment

                -, -i   Start with an empty environment
                -u      Remove variable from the environment

    envdir
        envdir DIR PROG ARGS

        Set various environment variables as specified by files in the
        directory DIR, run PROG

    envuidgid
        envuidgid USER PROG ARGS

        Set $UID to USER's uid and $GID to USER's gid, run PROG

    expand
        expand [-i] [-t N] [FILE]...

        Convert tabs to spaces, writing to stdout

                -i,--initial    Don't convert tabs after non blanks
                -t,--tabs=N     Tabstops every N chars

    expr
        expr EXPRESSION

        Print the value of EXPRESSION to stdout

        EXPRESSION may be:

                ARG1 | ARG2     ARG1 if it is neither null nor 0, otherwise ARG2
                ARG1 & ARG2     ARG1 if neither argument is null or 0, otherwise 0
                ARG1 < ARG2     1 if ARG1 is less than ARG2, else 0. Similarly:
                ARG1 <= ARG2
                ARG1 = ARG2
                ARG1 != ARG2
                ARG1 >= ARG2
                ARG1 > ARG2
                ARG1 + ARG2     Sum of ARG1 and ARG2. Similarly:
                ARG1 - ARG2
                ARG1 * ARG2
                ARG1 / ARG2
                ARG1 % ARG2
                STRING : REGEXP         Anchored pattern match of REGEXP in STRING
                match STRING REGEXP     Same as STRING : REGEXP
                substr STRING POS LENGTH Substring of STRING, POS counted from 1
                index STRING CHARS      Index in STRING where any CHARS is found, or 0
                length STRING           Length of STRING
                quote TOKEN             Interpret TOKEN as a string, even if
                                        it is a keyword like 'match' or an
                                        operator like '/'
                (EXPRESSION)            Value of EXPRESSION

        Beware that many operators need to be escaped or quoted for shells.
        Comparisons are arithmetic if both ARGs are numbers, else
        lexicographical. Pattern matches return the string matched between
        \( and \) or null; if \( and \) are not used, they return the number
        of characters matched or 0.

    fakeidentd
        fakeidentd [-fiw] [-b ADDR] [STRING]

        Provide fake ident (auth) service

                -f      Run in foreground
                -i      Inetd mode
                -w      Inetd 'wait' mode
                -b ADDR Bind to specified address
                STRING  Ident answer string (default: nobody)

    false
        false

        Return an exit code of FALSE (1)

    find
        find [PATH]... [OPTIONS] [ACTIONS]

        Search for files and perform actions on them. First failed action
        stops processing of current file. Defaults: PATH is current
        directory, action is '-print'

                -follow         Follow symlinks
                -xdev           Don't descend directories on other filesystems
                -maxdepth N     Descend at most N levels. -maxdepth 0 applies
                                actions to command line arguments only
                -mindepth N     Don't act on first N levels
                -depth          Act on directory *after* traversing it

        Actions:

                ( ACTIONS )     Group actions for -o / -a
                ! ACT           Invert ACT's success/failure
                ACT1 [-a] ACT2  If ACT1 fails, stop, else do ACT2
                ACT1 -o ACT2    If ACT1 succeeds, stop, else do ACT2
                                Note: -a has higher priority than -o
                -name PATTERN   Match file name (w/o directory name) to PATTERN
                -iname PATTERN  Case insensitive -name
                -path PATTERN   Match path to PATTERN
                -ipath PATTERN  Case insensitive -path
                -regex PATTERN  Match path to regex PATTERN
                -type X         File type is X (one of: f,d,l,b,c,...)
                -perm MASK      At least one mask bit (+MASK), all bits (-MASK),
                                or exactly MASK bits are set in file's mode
                -mtime DAYS     mtime is greater than (+N), less than (-N),
                                or exactly N days in the past
                -mmin MINS      mtime is greater than (+N), less than (-N),
                                or exactly N minutes in the past
                -newer FILE     mtime is more recent than FILE's
                -inum N         File has inode number N
                -user NAME/ID   File is owned by given user
                -group NAME/ID  File is owned by given group
                -size N[bck]    File size is N (c:bytes,k:kbytes,b:512 bytes(def.))
                                +/-N: file size is bigger/smaller than N
                -links N        Number of links is greater than (+N), less than (-N),
                                or exactly N
                -prune          If current file is directory, don't descend into it
        If none of the following actions is specified, -print is assumed
                -print          Print file name
                -print0         Print file name, NUL terminated
                -exec CMD ARG ; Run CMD with all instances of {} replaced by
                                file name. Fails if CMD exits with nonzero
                -delete         Delete current file/directory. Turns on -depth option

    fold
        fold [-bs] [-w WIDTH] [FILE]...

        Wrap input lines in each FILE (or stdin), writing to stdout

                -b      Count bytes rather than columns
                -s      Break at spaces
                -w      Use WIDTH columns instead of 80

    fsync
        fsync [-d] FILE...

        Write files' buffered blocks to disk

                -d      Avoid syncing metadata

    ftpd
        ftpd [-wvS] [-t N] [-T N] [DIR]

        Anonymous FTP server

        ftpd should be used as an inetd service. ftpd's line for inetd.conf:
        21 stream tcp nowait root ftpd ftpd /files/to/serve It also can be
        ran from tcpsvd:

                tcpsvd -vE 0.0.0.0 21 ftpd /files/to/serve

                -w      Allow upload
                -v      Log errors to stderr. -vv: verbose log
                -S      Log errors to syslog. -SS: verbose log
                -t,-T   Idle and absolute timeouts
                DIR     Change root to this directory

    ftpget
        ftpget [OPTIONS] HOST [LOCAL_FILE] REMOTE_FILE

        Retrieve a remote file via FTP

                -c,--continue   Continue previous transfer
                -v,--verbose    Verbose
                -u,--username   Username
                -p,--password   Password
                -P,--port       Port number

    ftpput
        ftpput [OPTIONS] HOST [REMOTE_FILE] LOCAL_FILE

        Store a local file on a remote machine via FTP

                -v,--verbose    Verbose
                -u,--username   Username
                -p,--password   Password
                -P,--port       Port number

    fuser
        fuser [OPTIONS] FILE or PORT/PROTO

        Find processes which use FILEs or PORTs

                -m      Find processes which use same fs as FILEs
                -4,-6   Search only IPv4/IPv6 space
                -s      Don't display PIDs
                -k      Kill found processes
                -SIGNAL Signal to send (default: KILL)

    getopt
        getopt [OPTIONS]

                -a,--alternative                Allow long options starting with single -
                -l,--longoptions=longopts       Long options to be recognized
                -n,--name=progname              The name under which errors are reported
                -o,--options=optstring          Short options to be recognized
                -q,--quiet                      Disable error reporting by getopt(3)
                -Q,--quiet-output               No normal output
                -s,--shell=shell                Set shell quoting conventions
                -T,--test                       Test for getopt(1) version
                -u,--unquoted                   Don't quote the output

    grep
        grep [-HhnlLoqvsriwFE] [-m N] [-A/B/C N] PATTERN/-e PATTERN.../-f
        FILE [FILE]...

        Search for PATTERN in FILEs (or stdin)

                -H      Add 'filename:' prefix
                -h      Do not add 'filename:' prefix
                -n      Add 'line_no:' prefix
                -l      Show only names of files that match
                -L      Show only names of files that don't match
                -c      Show only count of matching lines
                -o      Show only the matching part of line
                -q      Quiet. Return 0 if PATTERN is found, 1 otherwise
                -v      Select non-matching lines
                -s      Suppress open and read errors
                -r      Recurse
                -i      Ignore case
                -w      Match whole words only
                -F      PATTERN is a literal (not regexp)
                -E      PATTERN is an extended regexp
                -m N    Match up to N times per file
                -A N    Print N lines of trailing context
                -B N    Print N lines of leading context
                -C N    Same as '-A N -B N'
                -e PTRN Pattern to match
                -f FILE Read pattern from file

    groups
        groups [USER]

        Print the group memberships of USER or for the current process

    gunzip
        gunzip [-cft] [FILE]...

        Decompress FILEs (or stdin)

                -c      Write to stdout
                -f      Force
                -t      Test file integrity

    gzip
        gzip [-cfd] [FILE]...

        Compress FILEs (or stdin)

                -d      Decompress
                -c      Write to stdout
                -f      Force

    hd  hd FILE...

        hd is an alias for hexdump -C

    head
        head [OPTIONS] [FILE]...

        Print first 10 lines of each FILE (or stdin) to stdout. With more
        than one FILE, precede each with a filename header.

                -n N[kbm]       Print first N lines
                -c N[kbm]       Print first N bytes
                -q              Never print headers
                -v              Always print headers

        N may be suffixed by k (x1024), b (x512), or m (x1024^2).

    hexdump
        hexdump [-bcCdefnosvxR] [FILE]...

        Display FILEs (or stdin) in a user specified format

                -b              One-byte octal display
                -c              One-byte character display
                -C              Canonical hex+ASCII, 16 bytes per line
                -d              Two-byte decimal display
                -e FORMAT_STRING
                -f FORMAT_FILE
                -n LENGTH       Interpret only LENGTH bytes of input
                -o              Two-byte octal display
                -s OFFSET       Skip OFFSET bytes
                -v              Display all input data
                -x              Two-byte hexadecimal display
                -R              Reverse of 'hexdump -Cv'

    hostid
        hostid

        Print out a unique 32-bit identifier for the machine

    hostname
        hostname [OPTIONS] [HOSTNAME | -F FILE]

        Get or set hostname or DNS domain name

                -s      Short
                -i      Addresses for the hostname
                -d      DNS domain name
                -f      Fully qualified domain name
                -F FILE Use FILE's content as hostname

    httpd
        httpd [-ifv[v]] [-c CONFFILE] [-p [IP:]PORT] [-u USER[:GRP]] [-r
        REALM] [-h HOME] or httpd -d/-e/-m STRING

        Listen for incoming HTTP requests

                -i              Inetd mode
                -f              Don't daemonize
                -v[v]           Verbose
                -p [IP:]PORT    Bind to IP:PORT (default *:80)
                -u USER[:GRP]   Set uid/gid after binding to port
                -r REALM        Authentication Realm for Basic Authentication
                -h HOME         Home directory (default .)
                -c FILE         Configuration file (default {/etc,HOME}/httpd.conf)
                -m STRING       MD5 crypt STRING
                -e STRING       HTML encode STRING
                -d STRING       URL decode STRING

    id  id [OPTIONS] [USER]

        Print information about USER or the current user

                -u      User ID
                -g      Group ID
                -G      Supplementary group IDs
                -n      Print names instead of numbers
                -r      Print real ID instead of effective ID

    inetd
        inetd [-fe] [-q N] [-R N] [CONFFILE]

        Listen for network connections and launch programs

                -f      Run in foreground
                -e      Log to stderr
                -q N    Socket listen queue (default: 128)
                -R N    Pause services after N connects/min
                        (default: 0 - disabled)

    install
        install [-cdDsp] [-o USER] [-g GRP] [-m MODE] [SOURCE]... DEST

        Copy files and set attributes

                -c      Just copy (default)
                -d      Create directories
                -D      Create leading target directories
                -s      Strip symbol table
                -p      Preserve date
                -o USER Set ownership
                -g GRP  Set group ownership
                -m MODE Set permissions

    iostat
        iostat [-c] [-d] [-t] [-z] [-k|-m] [ALL|BLOCKDEV...] [INTERVAL
        [COUNT]]

        Report CPU and I/O statistics

                -c      Show CPU utilization
                -d      Show device utilization
                -t      Print current time
                -z      Omit devices with no activity
                -k      Use kb/s
                -m      Use Mb/s

    ipcalc
        ipcalc [OPTIONS] ADDRESS[[/]NETMASK] [NETMASK]

        Calculate IP network settings from a IP address

                -b,--broadcast  Display calculated broadcast address
                -n,--network    Display calculated network address
                -m,--netmask    Display default netmask for IP
                -p,--prefix     Display the prefix for IP/NETMASK
                -h,--hostname   Display first resolved host name
                -s,--silent     Don't ever display error messages

    kill
        kill [-l] [-SIG] PID...

        Send a signal (default: TERM) to given PIDs

                -l      List all signal names and numbers

    killall
        killall [-l] [-q] [-SIG] PROCESS_NAME...

        Send a signal (default: TERM) to given processes

                -l      List all signal names and numbers
                -q      Don't complain if no processes were killed

    killall5
        killall5 [-l] [-SIG] [-o PID]...

        Send a signal (default: TERM) to all processes outside current
        session

                -l      List all signal names and numbers
                -o PID  Don't signal this PID

    less
        less [-EMNmh~I?] [FILE]...

        View FILE (or stdin) one screenful at a time

                -E      Quit once the end of a file is reached
                -M,-m   Display status line with line numbers
                        and percentage through the file
                -N      Prefix line number to each line
                -I      Ignore case in all searches
                -~      Suppress ~s displayed past the end of the file

    ln  ln [OPTIONS] TARGET... LINK|DIR

        Create a link LINK or DIR/TARGET to the specified TARGET(s)

                -s      Make symlinks instead of hardlinks
                -f      Remove existing destinations
                -n      Don't dereference symlinks - treat like normal file
                -b      Make a backup of the target (if exists) before link operation
                -S suf  Use suffix instead of ~ when making backup files

    logger
        logger [OPTIONS] [MESSAGE]

        Write MESSAGE (or stdin) to syslog

                -s      Log to stderr as well as the system log
                -t TAG  Log using the specified tag (defaults to user name)
                -p PRIO Priority (numeric or facility.level pair)

    logname
        logname

        Print the name of the current user

    logread
        logread [-f]

        Show messages in syslogd's circular buffer

                -f      Output data as log grows

    lpd lpd SPOOLDIR [HELPER [ARGS]]

        SPOOLDIR must contain (symlinks to) device nodes or directories with
        names matching print queue names. In the first case, jobs are sent
        directly to the device. Otherwise each job is stored in queue
        directory and HELPER program is called. Name of file to print is
        passed in $DATAFILE variable. Example:

                tcpsvd -E 0 515 softlimit -m 999999 lpd /var/spool ./print

    lpq lpq [-P queue[@host[:port]]] [-U USERNAME] [-d JOBID]... [-fs]

                -P      lp service to connect to (else uses $PRINTER)
                -d      Delete jobs
                -f      Force any waiting job to be printed
                -s      Short display

    lpr lpr -P queue[@host[:port]] -U USERNAME -J TITLE -Vmh [FILE]...

                -P      lp service to connect to (else uses $PRINTER)
                -m      Send mail on completion
                -h      Print banner page too
                -V      Verbose

    ls  ls [-1AaCxdLHRFplinsehrSXvctu] [-w WIDTH] [FILE]...

        List directory contents

                -1      One column output
                -a      Include entries which start with .
                -A      Like -a, but exclude . and ..
                -C      List by columns
                -x      List by lines
                -d      List directory entries instead of contents
                -L      Follow symlinks
                -H      Follow symlinks on command line
                -R      Recurse
                -p      Append / to dir entries
                -F      Append indicator (one of */=@|) to entries
                -l      Long listing format
                -i      List inode numbers
                -n      List numeric UIDs and GIDs instead of names
                -s      List allocated blocks
                -e      List full date and time
                -h      List sizes in human readable format (1K 243M 2G)
                -r      Sort in reverse order
                -S      Sort by size
                -X      Sort by extension
                -v      Sort by version
                -c      With -l: sort by ctime
                -t      With -l: sort by mtime
                -u      With -l: sort by atime
                -w N    Assume the terminal is N columns wide
                --color[={always,never,auto}]   Control coloring

    lzcat
        lzcat FILE

        Decompress to stdout

    lzma
        lzma -d [-cf] [FILE]...

        Decompress FILE (or stdin)

                -d      Decompress
                -c      Write to stdout
                -f      Force

    lzop
        lzop [-cfvd123456789CF] [FILE]...

                -1..9   Compression level
                -d      Decompress
                -c      Write to stdout
                -f      Force
                -v      Verbose
                -F      Don't store or verify checksum
                -C      Also write checksum of compressed block

    lzopcat
        lzopcat [-vCF] [FILE]...

                -v      Verbose
                -F      Don't store or verify checksum

    makemime
        makemime [OPTIONS] [FILE]...

        Create multipart MIME-encoded message from FILEs

                -o FILE Output. Default: stdout
                -a HDR  Add header. Examples:
                        "From: user@host.org", "Date: `date -R`"
                -c CT   Content type. Default: text/plain
                -C CS   Charset. Default: us-ascii

        Other options are silently ignored

    man man [-aw] [MANPAGE]...

        Format and display manual page

                -a      Display all pages
                -w      Show page locations

    md5sum
        md5sum [-c[sw]] [FILE]...

        Print or check MD5 checksums

                -c      Check sums against list in FILEs
                -s      Don't output anything, status code shows success
                -w      Warn about improperly formatted checksum lines

    mesg
        mesg [y|n]

        Control write access to your terminal y Allow write access to your
        terminal n Disallow write access to your terminal

    microcom
        microcom [-d DELAY] [-t TIMEOUT] [-s SPEED] [-X] TTY

        Copy bytes for stdin to TTY and from TTY to stdout

                -d      Wait up to DELAY ms for TTY output before sending every
                        next byte to it
                -t      Exit if both stdin and TTY are silent for TIMEOUT ms
                -s      Set serial line to SPEED
                -X      Disable special meaning of NUL and Ctrl-X from stdin

    mkdir
        mkdir [OPTIONS] DIRECTORY...

        Create DIRECTORY

                -m MODE Mode
                -p      No error if exists; make parent directories as needed

    mkfifo
        mkfifo [-m MODE] NAME

        Create named pipe

                -m MODE Mode (default a=rw)

    mknod
        mknod [-m MODE] NAME TYPE MAJOR MINOR

        Create a special file (block, character, or pipe)

                -m MODE Creation mode (default a=rw)
        TYPE:
                b       Block device
                c or u  Character device
                p       Named pipe (MAJOR and MINOR are ignored)

    mkpasswd
        mkpasswd [OPTIONS] [PASSWORD] [SALT]

        Crypt PASSWORD using crypt(3)

                -P,--password-fd=N      Read password from fd N
                -m,--method=TYPE        Encryption method
                -S,--salt=SALT

    mktemp
        mktemp [-dt] [-p DIR] [TEMPLATE]

        Create a temporary file with name based on TEMPLATE and print its
        name. TEMPLATE must end with XXXXXX (e.g. [/dir/]nameXXXXXX).
        Without TEMPLATE, -t tmp.XXXXXX is assumed.

                -d      Make directory, not file
                -t      Prepend base directory name to TEMPLATE
                -p DIR  Use DIR as a base directory (implies -t)

        Base directory is: -p DIR, else $TMPDIR, else /tmp

    more
        more [FILE]...

        View FILE (or stdin) one screenful at a time

    mpstat
        mpstat [-A] [-I SUM|CPU|ALL|SCPU] [-u] [-P num|ALL] [INTERVAL
        [COUNT]]

        Per-processor statistics

                -A                      Same as -I ALL -u -P ALL
                -I SUM|CPU|ALL|SCPU     Report interrupt statistics
                -P num|ALL              Processor to monitor
                -u                      Report CPU utilization

    mt  mt [-f device] opcode value

        Control magnetic tape drive operation

        Available Opcodes:

        bsf bsfm bsr bss datacompression drvbuffer eof eom erase fsf fsfm
        fsr fss load lock mkpart nop offline ras1 ras2 ras3 reset retension
        rewind rewoffline seek setblk setdensity setpart tell unload unlock
        weof wset

    mv  mv [-fin] SOURCE DEST or: mv [-fin] SOURCE... DIRECTORY

        Rename SOURCE to DEST, or move SOURCE(s) to DIRECTORY

                -f      Don't prompt before overwriting
                -i      Interactive, prompt before overwrite
                -n      Don't overwrite an existing file

    nc  nc [-iN] [-wN] [-l] [-p PORT] [-f FILE|IPADDR PORT] [-e PROG]

        Open a pipe to IP:PORT or FILE

                -e PROG Run PROG after connect
                -l      Listen mode, for inbound connects
                        (use -l twice with -e for persistent server)
                -p PORT Local port
                -w SEC  Timeout for connect
                -i SEC  Delay interval for lines sent
                -f FILE Use file (ala /dev/ttyS0) instead of network

    nice
        nice [-n ADJUST] [PROG ARGS]

        Change scheduling priority, run PROG

                -n ADJUST       Adjust priority by ADJUST

    nmeter
        nmeter [-d MSEC] FORMAT_STRING

        Monitor system in real time

         -d MSEC        Milliseconds between updates (default:1000)

        Format specifiers:

         %Nc or %[cN]   CPU. N - bar size (default:10)
                        (displays: S:system U:user N:niced D:iowait I:irq i:softirq)
         %[nINTERFACE]  Network INTERFACE
         %m             Allocated memory
         %[mf]          Free memory
         %[mt]          Total memory
         %s             Allocated swap
         %f             Number of used file descriptors
         %Ni            Total/specific IRQ rate
         %x             Context switch rate
         %p             Forks
         %[pn]          # of processes
         %b             Block io
         %Nt            Time (with N decimal points)
         %r             Print <cr> instead of <lf> at EOL

    nohup
        nohup PROG ARGS

        Run PROG immune to hangups, with output to a non-tty

    nslookup
        nslookup [HOST] [SERVER]

        Query the nameserver for the IP address of the given HOST optionally
        using a specified DNS server

    od  od [-abcdfhilovxs] [-t TYPE] [-A RADIX] [-N SIZE] [-j SKIP] [-S
        MINSTR] [-w WIDTH] [FILE...]

        Print FILEs (or stdin) unambiguously, as octal bytes by default

    patch
        patch [OPTIONS] [ORIGFILE [PATCHFILE]]

                -p,--strip N            Strip N leading components from file names
                -i,--input DIFF         Read DIFF instead of stdin
                -R,--reverse            Reverse patch
                -N,--forward            Ignore already applied patches
                -E,--remove-empty-files Remove output files if they become empty

    pgrep
        pgrep [-flnovx] [-s SID|-P PPID|PATTERN]

        Display process(es) selected by regex PATTERN

                -l      Show command name too
                -f      Match against entire command line
                -n      Show the newest process only
                -o      Show the oldest process only
                -v      Negate the match
                -x      Match whole name (not substring)
                -s      Match session ID (0 for current)
                -P      Match parent process ID

    pidof
        pidof [OPTIONS] [NAME]...

        List PIDs of all processes with names that match NAMEs

                -s      Show only one PID
                -o PID  Omit given pid
                        Use %PPID to omit pid of pidof's parent

    pkill
        pkill [-l|-SIGNAL] [-fnovx] [-s SID|-P PPID|PATTERN]

        Send a signal to process(es) selected by regex PATTERN

                -l      List all signals
                -f      Match against entire command line
                -n      Signal the newest process only
                -o      Signal the oldest process only
                -v      Negate the match
                -x      Match whole name (not substring)
                -s      Match session ID (0 for current)
                -P      Match parent process ID

    popmaildir
        popmaildir [OPTIONS] MAILDIR [CONN_HELPER ARGS]

        Fetch content of remote mailbox to local maildir

                -s              Skip authorization
                -T              Get messages with TOP instead of RETR
                -k              Keep retrieved messages on the server
                -t SEC          Network timeout
                -F "PROG ARGS"  Filter program (may be repeated)
                -M "PROG ARGS"  Delivery program

        Fetch from plain POP3 server: popmaildir -k DIR nc pop3.server.com
        110 <user_and_pass.txt Fetch from SSLed POP3 server and delete
        fetched emails: popmaildir DIR -- openssl s_client -quiet -connect
        pop3.server.com:995 <user_and_pass.txt

    printenv
        printenv [VARIABLE]...

        Print environment VARIABLEs. If no VARIABLE specified, print all.

    printf
        printf FORMAT [ARGUMENT]...

        Format and print ARGUMENT(s) according to FORMAT, where FORMAT
        controls the output exactly as in C printf

    ps  ps [-o COL1,COL2=HEADER]

        Show list of processes

                -o COL1,COL2=HEADER     Select columns for display

    pscan
        pscan [-cb] [-p MIN_PORT] [-P MAX_PORT] [-t TIMEOUT] [-T MIN_RTT]
        HOST

        Scan a host, print all open ports

                -c      Show closed ports too
                -b      Show blocked ports too
                -p      Scan from this port (default 1)
                -P      Scan up to this port (default 1024)
                -t      Timeout (default 5000 ms)
                -T      Minimum rtt (default 5 ms, increase for congested hosts)

    pstree
        pstree [-p] [PID|USER]

        Display process tree, optionally start from USER or PID

                -p      Show pids

    pwd pwd

        Print the full filename of the current working directory

    pwdx
        pwdx PID...

        Show current directory for PIDs

    readlink
        readlink [-fnv] FILE

        Display the value of a symlink

                -f      Canonicalize by following all symlinks
                -n      Don't add newline
                -v      Verbose

    realpath
        realpath FILE...

        Return the absolute pathnames of given FILE

    reformime
        reformime [OPTIONS]

        Parse MIME-encoded message on stdin

                -x PREFIX       Extract content of MIME sections to files
                -X PROG ARGS    Filter content of MIME sections through PROG
                                Must be the last option

        Other options are silently ignored

    renice
        renice {{-n INCREMENT} | PRIORITY} [[-p | -g | -u] ID...]

        Change scheduling priority for a running process

                -n      Adjust current nice value (smaller is faster)
                -p      Process id(s) (default)
                -g      Process group id(s)
                -u      Process user name(s) and/or id(s)

    reset
        reset

        Reset the screen

    resize
        resize

        Resize the screen

    rm  rm [-irf] FILE...

        Remove (unlink) FILEs

                -i      Always prompt before removing
                -f      Never prompt
                -R,-r   Recurse

    rmdir
        rmdir [OPTIONS] DIRECTORY...

        Remove DIRECTORY if it is empty

                -p|--parents    Include parents
                --ignore-fail-on-non-empty

    rpm rpm -i PACKAGE.rpm; rpm -qp[ildc] PACKAGE.rpm

        Manipulate RPM packages

        Commands:

                -i      Install package
                -qp     Query package
                -i      Show information
                -l      List contents
                -d      List documents
                -c      List config files

    rpm2cpio
        rpm2cpio package.rpm

        Output a cpio archive of the rpm file

    run-parts
        run-parts [-t] [-l] [-a ARG] [-u MASK] DIRECTORY

        Run a bunch of scripts in DIRECTORY

                -t      Print what would be run, but don't actually run anything
                -a ARG  Pass ARG as argument for every program
                -u MASK Set the umask to MASK before running every program
                -l      Print names of all matching files even if they are not executable

    runsv
        runsv DIR

        Start and monitor a service and optionally an appendant log service

    runsvdir
        runsvdir [-P] [-s SCRIPT] DIR

        Start a runsv process for each subdirectory. If it exits, restart
        it.

                -P              Put each runsv in a new session
                -s SCRIPT       Run SCRIPT <signo> after signal is processed

    sed sed [-efinr] SED_CMD [FILE]...

                -e CMD  Add CMD to sed commands to be executed
                -f FILE Add FILE contents to sed commands to be executed
                -i      Edit files in-place (else sends result to stdout)
                -n      Suppress automatic printing of pattern space
                -r      Use extended regex syntax

        If no -e or -f, the first non-option argument is the sed command
        string. Remaining arguments are input files (stdin if none).

    sendmail
        sendmail [OPTIONS] [RECIPIENT_EMAIL]...

        Read email from stdin and send it

        Standard options:

                -t              Read additional recipients from message body
                -f SENDER       Sender (required)
                -o OPTIONS      Various options. -oi implied, others are ignored
                -i              -oi synonym. implied and ignored

        Busybox specific options:

                -v              Verbose
                -w SECS         Network timeout
                -H 'PROG ARGS'  Run connection helper
                                Examples:
                                -H 'exec openssl s_client -quiet -tls1 -starttls smtp
                                        -connect smtp.gmail.com:25' <email.txt
                                        [4<username_and_passwd.txt | -au<username> -ap<password>]
                                -H 'exec openssl s_client -quiet -tls1
                                        -connect smtp.gmail.com:465' <email.txt
                                        [4<username_and_passwd.txt | -au<username> -ap<password>]
                -S HOST[:PORT]  Server
                -au<username>   Username for AUTH LOGIN
                -ap<password>   Password for AUTH LOGIN
                -am<method>     Authentication method. Ignored. LOGIN is implied

        Other options are silently ignored; -oi -t is implied Use makemime
        applet to create message with attachments

    seq seq [-w] [-s SEP] [FIRST [INC]] LAST

        Print numbers from FIRST to LAST, in steps of INC. FIRST, INC
        default to 1.

                -w      Pad to last with leading zeros
                -s SEP  String separator

    setsid
        setsid PROG ARGS

        Run PROG in a new session. PROG will have no controlling terminal
        and will not be affected by keyboard signals (Ctrl-C etc). See
        setsid(2) for details.

    setuidgid
        setuidgid USER PROG ARGS

        Set uid and gid to USER's uid and gid, drop supplementary group ids,
        run PROG

    sha1sum
        sha1sum [-c[sw]] [FILE]...

        Print or check SHA1 checksums

                -c      Check sums against list in FILEs
                -s      Don't output anything, status code shows success
                -w      Warn about improperly formatted checksum lines

    sha256sum
        sha256sum [-c[sw]] [FILE]...

        Print or check SHA256 checksums

                -c      Check sums against list in FILEs
                -s      Don't output anything, status code shows success
                -w      Warn about improperly formatted checksum lines

    sha512sum
        sha512sum [-c[sw]] [FILE]...

        Print or check SHA512 checksums

                -c      Check sums against list in FILEs
                -s      Don't output anything, status code shows success
                -w      Warn about improperly formatted checksum lines

    sleep
        sleep [N]...

        Pause for a time equal to the total of the args given, where each
        arg can have an optional suffix of (s)econds, (m)inutes, (h)ours, or
        (d)ays

    smemcap
        smemcap >SMEMDATA.TAR

        Collect memory usage data in /proc and write it to stdout

    softlimit
        softlimit [-a BYTES] [-m BYTES] [-d BYTES] [-s BYTES] [-l BYTES] [-f
        BYTES] [-c BYTES] [-r BYTES] [-o N] [-p N] [-t N] PROG ARGS

        Set soft resource limits, then run PROG

                -a BYTES        Limit total size of all segments
                -m BYTES        Same as -d BYTES -s BYTES -l BYTES -a BYTES
                -d BYTES        Limit data segment
                -s BYTES        Limit stack segment
                -l BYTES        Limit locked memory size
                -o N            Limit number of open files per process
                -p N            Limit number of processes per uid
        Options controlling file sizes:

                -f BYTES        Limit output file sizes
                -c BYTES        Limit core file size
        Efficiency opts:

                -r BYTES        Limit resident set size
                -t N            Limit CPU time, process receives
                                a SIGXCPU after N seconds

    sort
        sort [-nrugMcszbdfimSTokt] [-o FILE] [-k
        start[.offset][opts][,end[.offset][opts]] [-t CHAR] [FILE]...

        Sort lines of text

                -b      Ignore leading blanks
                -c      Check whether input is sorted
                -d      Dictionary order (blank or alphanumeric only)
                -f      Ignore case
                -g      General numerical sort
                -i      Ignore unprintable characters
                -k      Sort key
                -M      Sort month
                -n      Sort numbers
                -o      Output to file
                -k      Sort by key
                -t CHAR Key separator
                -r      Reverse sort order
                -s      Stable (don't sort ties alphabetically)
                -u      Suppress duplicate lines
                -z      Lines are terminated by NUL, not newline
                -mST    Ignored for GNU compatibility

    split
        split [OPTIONS] [INPUT [PREFIX]]

                -b N[k|m]       Split by N (kilo|mega)bytes
                -l N            Split by N lines
                -a N            Use N letters as suffix

    start-stop-daemon
        start-stop-daemon [OPTIONS] [-S|-K] ... [-- ARGS...]

        Search for matching processes, and then -K: stop all matching
        processes. -S: start a process unless a matching process is found.

        Process matching:

                -u,--user USERNAME|UID  Match only this user's processes
                -n,--name NAME          Match processes with NAME
                                        in comm field in /proc/PID/stat
                -x,--exec EXECUTABLE    Match processes with this command
                                        in /proc/PID/cmdline
                -p,--pidfile FILE       Match a process with PID from the file
                All specified conditions must match
        -S only:
                -x,--exec EXECUTABLE    Program to run
                -a,--startas NAME       Zeroth argument
                -b,--background         Background
                -N,--nicelevel N        Change nice level
                -c,--chuid USER[:[GRP]] Change to user/group
                -m,--make-pidfile       Write PID to the pidfile specified by -p
        -K only:
                -s,--signal SIG         Signal to send
                -t,--test               Match only, exit with 0 if a process is found
        Other:

                -o,--oknodo             Exit with status 0 if nothing is done
                -v,--verbose            Verbose
                -q,--quiet              Quiet

    stat
        stat [OPTIONS] FILE...

        Display file (default) or filesystem status

                -c fmt  Use the specified format
                -f      Display filesystem status
                -L      Follow links
                -t      Display info in terse form

        Valid format sequences for files:

         %a     Access rights in octal
         %A     Access rights in human readable form
         %b     Number of blocks allocated (see %B)
         %B     The size in bytes of each block reported by %b
         %d     Device number in decimal
         %D     Device number in hex
         %f     Raw mode in hex
         %F     File type
         %g     Group ID of owner
         %G     Group name of owner
         %h     Number of hard links
         %i     Inode number
         %n     File name
         %N     File name, with -> TARGET if symlink
         %o     I/O block size
         %s     Total size, in bytes
         %t     Major device type in hex
         %T     Minor device type in hex
         %u     User ID of owner
         %U     User name of owner
         %x     Time of last access
         %X     Time of last access as seconds since Epoch
         %y     Time of last modification
         %Y     Time of last modification as seconds since Epoch
         %z     Time of last change
         %Z     Time of last change as seconds since Epoch

        Valid format sequences for file systems:

         %a     Free blocks available to non-superuser
         %b     Total data blocks in file system
         %c     Total file nodes in file system
         %d     Free file nodes in file system
         %f     Free blocks in file system
         %i     File System ID in hex
         %l     Maximum length of filenames
         %n     File name
         %s     Block size (for faster transfer)
         %S     Fundamental block size (for block counts)
         %t     Type in hex
         %T     Type in human readable form

    strings
        strings [-afo] [-n LEN] [FILE]...

        Display printable strings in a binary file

                -a      Scan whole file (default)
                -f      Precede strings with filenames
                -n LEN  At least LEN characters form a string (default 4)
                -o      Precede strings with decimal offsets

    stty
        stty [-a|g] [-F DEVICE] [SETTING]...

        Without arguments, prints baud rate, line discipline, and deviations
        from stty sane

                -F DEVICE       Open device instead of stdin
                -a              Print all current settings in human-readable form
                -g              Print in stty-readable form
                [SETTING]       See manpage

    sum sum [-rs] [FILE]...

        Checksum and count the blocks in a file

                -r      Use BSD sum algorithm (1K blocks)
                -s      Use System V sum algorithm (512byte blocks)

    sv  sv [-v] [-w SEC] CMD SERVICE_DIR...

        Control services monitored by runsv supervisor. Commands (only first
        character is enough):

        status: query service status up: if service isn't running, start it.
        If service stops, restart it once: like 'up', but if service stops,
        don't restart it down: send TERM and CONT signals. If ./run exits,
        start ./finish if it exists. After it stops, don't restart service
        exit: send TERM and CONT signals to service and log service. If they
        exit, runsv exits too pause, cont, hup, alarm, interrupt, quit, 1,
        2, term, kill: send STOP, CONT, HUP, ALRM, INT, QUIT, USR1, USR2,
        TERM, KILL signal to service

    svlogd
        svlogd [-ttv] [-r C] [-R CHARS] [-l MATCHLEN] [-b BUFLEN] DIR...

        Continuously read log data from stdin and write to rotated log files
        in DIRs

        DIR/config file modifies behavior: sSIZE - when to rotate logs nNUM
        - number of files to retain !PROG - process rotated log with PROG
        +,-PATTERN - (de)select line for logging E,ePATTERN - (de)select
        line for stderr

    sync
        sync

        Write all buffered blocks to disk

    sysctl
        sysctl [OPTIONS] [VALUE]...

        Configure kernel parameters at runtime

                -n      Don't print key names
                -e      Don't warn about unknown keys
                -w      Change sysctl setting
                -p FILE Load sysctl settings from FILE (default /etc/sysctl.conf)
                -a      Display all values
                -A      Display all values in table form

    syslogd
        syslogd [OPTIONS]

        System logging utility

                -n              Run in foreground
                -O FILE         Log to FILE (default:/var/log/messages)
                -l N            Log only messages more urgent than prio N (1-8)
                -S              Smaller output
                -s SIZE         Max size (KB) before rotation (default:200KB, 0=off)
                -b N            N rotated logs to keep (default:1, max=99, 0=purge)
                -R HOST[:PORT]  Log to IP or hostname on PORT (default PORT=514/UDP)
                -L              Log locally and via network (default is network only if -R)
                -D              Drop duplicates
                -C[size_kb]     Log to shared mem buffer (use logread to read it)
                -f FILE         Use FILE as config (default:/etc/syslog.conf)

    tac tac [FILE]...

        Concatenate FILEs and print them in reverse

    tail
        tail [OPTIONS] [FILE]...

        Print last 10 lines of each FILE (or stdin) to stdout. With more
        than one FILE, precede each with a filename header.

                -f              Print data as file grows
                -s SECONDS      Wait SECONDS between reads with -f
                -n N[kbm]       Print last N lines
                -c N[kbm]       Print last N bytes
                -q              Never print headers
                -v              Always print headers

        N may be suffixed by k (x1024), b (x512), or m (x1024^2). If N
        starts with a '+', output begins with the Nth item from the start of
        each file, not from the end.

    tar tar -[cxtzjahmvO] [-X FILE] [-T FILE] [-f TARFILE] [-C DIR]
        [FILE]...

        Create, extract, or list files from a tar file

        Operation:

                c       Create
                x       Extract
                t       List
                f       Name of TARFILE ('-' for stdin/out)
                C       Change to DIR before operation
                v       Verbose
                z       (De)compress using gzip
                j       (De)compress using bzip2
                a       (De)compress using lzma
                O       Extract to stdout
                h       Follow symlinks
                m       Don't restore mtime
                exclude File to exclude
                X       File with names to exclude
                T       File with names to include

    tcpsvd
        tcpsvd [-hEv] [-c N] [-C N[:MSG]] [-b N] [-u USER] [-l NAME] IP PORT
        PROG

        Create TCP socket, bind to IP:PORT and listen for incoming
        connection. Run PROG for each connection.

                IP              IP to listen on, 0 = all
                PORT            Port to listen on
                PROG ARGS       Program to run
                -l NAME         Local hostname (else looks up local hostname in DNS)
                -u USER[:GRP]   Change to user/group after bind
                -c N            Handle up to N connections simultaneously
                -b N            Allow a backlog of approximately N TCP SYNs
                -C N[:MSG]      Allow only up to N connections from the same IP
                                New connections from this IP address are closed
                                immediately. MSG is written to the peer before close
                -h              Look up peer's hostname
                -E              Don't set up environment variables
                -v              Verbose

    tee tee [-ai] [FILE]...

        Copy stdin to each FILE, and also to stdout

                -a      Append to the given FILEs, don't overwrite
                -i      Ignore interrupt signals (SIGINT)

    telnet
        telnet [-a] [-l USER] HOST [PORT]

        Connect to telnet server

                -a      Automatic login with $USER variable
                -l USER Automatic login as USER

    telnetd
        telnetd [OPTIONS]

        Handle incoming telnet connections

                -l LOGIN        Exec LOGIN on connect
                -f ISSUE_FILE   Display ISSUE_FILE instead of /etc/issue
                -K              Close connection as soon as login exits
                                (normally wait until all programs close slave pty)
                -p PORT         Port to listen on
                -b ADDR[:PORT]  Address to bind to
                -F              Run in foreground
                -i              Inetd mode
                -w SEC          Inetd 'wait' mode, linger time SEC
                -S              Log to syslog (implied by -i or without -F and -w)

    test
        test EXPRESSION ]

        Check file types, compare values etc. Return a 0/1 exit code
        depending on logical value of EXPRESSION

    tftp
        tftp [OPTIONS] HOST [PORT]

        Transfer a file from/to tftp server

                -l FILE Local FILE
                -r FILE Remote FILE
                -g      Get file
                -p      Put file

    tftpd
        tftpd [-cr] [-u USER] [DIR]

        Transfer a file on tftp client's request

        tftpd should be used as an inetd service. tftpd's line for
        inetd.conf: 69 dgram udp nowait root tftpd tftpd -l /files/to/serve
        It also can be ran from udpsvd:

                udpsvd -vE 0.0.0.0 69 tftpd /files/to/serve

                -r      Prohibit upload
                -c      Allow file creation via upload
                -u      Access files as USER
                -l      Log to syslog (inetd mode requires this)

    time
        time [-v] PROG ARGS

        Run PROG, display resource usage when it exits

                -v      Verbose

    timeout
        timeout [-t SECS] [-s SIG] PROG ARGS

        Runs PROG. Sends SIG to it if it is not gone in SECS seconds.
        Defaults: SECS: 10, SIG: TERM.

    touch
        touch [-c] [-d DATE] [-r FILE] FILE [FILE]...

        Update the last-modified date on the given FILE[s]

                -c      Don't create files
                -d DT   Date/time to use
                -r FILE Use FILE's date/time

    tr  tr [-cds] STRING1 [STRING2]

        Translate, squeeze, or delete characters from stdin, writing to
        stdout

                -c      Take complement of STRING1
                -d      Delete input characters coded STRING1
                -s      Squeeze multiple output characters of STRING2 into one character

    true
        true

        Return an exit code of TRUE (0)

    tty tty

        Print file name of stdin's terminal

                -s      Print nothing, only return exit status

    ttysize
        ttysize [w] [h]

        Print dimension(s) of stdin's terminal, on error return 80x25

    udpsvd
        udpsvd [-hEv] [-c N] [-u USER] [-l NAME] IP PORT PROG

        Create UDP socket, bind to IP:PORT and wait for incoming packets.
        Run PROG for each packet, redirecting all further packets with same
        peer ip:port to it.

                IP              IP to listen on, 0 = all
                PORT            Port to listen on
                PROG ARGS       Program to run
                -l NAME         Local hostname (else looks up local hostname in DNS)
                -u USER[:GRP]   Change to user/group after bind
                -c N            Handle up to N connections simultaneously
                -h              Look up peer's hostname
                -E              Don't set up environment variables
                -v              Verbose

    uname
        uname [-amnrspv]

        Print system information

                -a      Print all
                -m      The machine (hardware) type
                -n      Hostname
                -r      OS release
                -s      OS name (default)
                -p      Processor type
                -v      OS version

    uncompress
        uncompress [-cf] [FILE]...

        Decompress .Z file[s]

                -c      Write to stdout
                -f      Overwrite

    unexpand
        unexpand [-fa][-t N] [FILE]...

        Convert spaces to tabs, writing to stdout

                -a,--all        Convert all blanks
                -f,--first-only Convert only leading blanks
                -t,--tabs=N     Tabstops every N chars

    uniq
        uniq [-cdu][-f,s,w N] [INPUT [OUTPUT]]

        Discard duplicate lines

                -c      Prefix lines by the number of occurrences
                -d      Only print duplicate lines
                -u      Only print unique lines
                -f N    Skip first N fields
                -s N    Skip first N chars (after any skipped fields)
                -w N    Compare N characters in line

    unix2dos
        unix2dos [-ud] [FILE]

        Convert FILE in-place from Unix to DOS format. When no file is
        given, use stdin/stdout.

                -u      dos2unix
                -d      unix2dos

    unlzma
        unlzma [-cf] [FILE]...

        Decompress FILE (or stdin)

                -c      Write to stdout
                -f      Force

    unlzop
        unlzop [-cfvCF] [FILE]...

                -c      Write to stdout
                -f      Force
                -v      Verbose
                -F      Don't store or verify checksum

    unxz
        unxz [-cf] [FILE]...

        Decompress FILE (or stdin)

                -c      Write to stdout
                -f      Force

    unzip
        unzip [-opts[modifiers]] FILE[.zip] [LIST] [-x XLIST] [-d DIR]

        Extract files from ZIP archives

                -l      List archive contents (with -q for short form)
                -n      Never overwrite files (default)
                -o      Overwrite
                -p      Send output to stdout
                -q      Quiet
                -x XLST Exclude these files
                -d DIR  Extract files into DIR

    usleep
        usleep N

        Pause for N microseconds

    uudecode
        uudecode [-o OUTFILE] [INFILE]

        Uudecode a file Finds outfile name in uuencoded source unless -o is
        given

    uuencode
        uuencode [-m] [INFILE] STORED_FILENAME

        Uuencode a file to stdout

                -m      Use base64 encoding per RFC1521

    vlock
        vlock [-a]

        Lock a virtual terminal. A password is required to unlock.

                -a      Lock all VTs

    volname
        volname [DEVICE]

        Show CD volume name of the DEVICE (default /dev/cdrom)

    watch
        watch [-n SEC] [-t] PROG ARGS

        Run PROG periodically

                -n      Loop period in seconds (default 2)
                -t      Don't print header

    wc  wc [-cmlwL] [FILE]...

        Count lines, words, and bytes for each FILE (or stdin)

                -c      Count bytes
                -m      Count characters
                -l      Count newlines
                -w      Count words
                -L      Print longest line length

    which
        which [COMMAND]...

        Locate a COMMAND

    whoami
        whoami

        Print the user name associated with the current effective user id

    whois
        whois [-h SERVER] [-p PORT] NAME...

        Query WHOIS info about NAME

                -h,-p   Server to query

    xargs
        xargs [OPTIONS] [PROG ARGS]

        Run PROG on every item given by stdin

                -p      Ask user whether to run each command
                -r      Don't run command if input is empty
                -0      Input is separated by NUL characters
                -t      Print the command on stderr before execution
                -e[STR] STR stops input processing
                -n N    Pass no more than N args to PROG
                -s N    Pass command line of no more than N bytes
                -x      Exit if size is exceeded

    xz  xz -d [-cf] [FILE]...

        Decompress FILE (or stdin)

                -d      Decompress
                -c      Write to stdout
                -f      Force

    xzcat
        xzcat FILE

        Decompress to stdout

    yes yes [STRING]

        Repeatedly output a line with STRING, or 'y'

    zcat
        zcat FILE

        Decompress to stdout

LIBC NSS
    GNU Libc (glibc) uses the Name Service Switch (NSS) to configure the
    behavior of the C library for the local environment, and to configure
    how it reads system data, such as passwords and group information. This
    is implemented using an /etc/nsswitch.conf configuration file, and using
    one or more of the /lib/libnss_* libraries. BusyBox tries to avoid using
    any libc calls that make use of NSS. Some applets however, such as login
    and su, will use libc functions that require NSS.

    If you enable CONFIG_USE_BB_PWD_GRP, BusyBox will use internal functions
    to directly access the /etc/passwd, /etc/group, and /etc/shadow files
    without using NSS. This may allow you to run your system without the
    need for installing any of the NSS configuration files and libraries.

    When used with glibc, the BusyBox 'networking' applets will similarly
    require that you install at least some of the glibc NSS stuff (in
    particular, /etc/nsswitch.conf, /lib/libnss_dns*, /lib/libnss_files*,
    and /lib/libresolv*).

    Shameless Plug: As an alternative, one could use a C library such as
    uClibc. In addition to making your system significantly smaller, uClibc
    does not require the use of any NSS support files or libraries.

MAINTAINER
    Denis Vlasenko <vda.linux@googlemail.com>

AUTHORS
    The following people have contributed code to BusyBox whether they know
    it or not. If you have written code included in BusyBox, you should
    probably be listed here so you can obtain your bit of eternal glory. If
    you should be listed here, or the description of what you have done
    needs more detail, or is incorrect, please send in an update.

    Emanuele Aina <emanuele.aina@tiscali.it> run-parts

    Erik Andersen <andersen@codepoet.org>

        Tons of new stuff, major rewrite of most of the
        core apps, tons of new apps as noted in header files.
        Lots of tedious effort writing these boring docs that
        nobody is going to actually read.

    Laurence Anderson <l.d.anderson@warwick.ac.uk>

        rpm2cpio, unzip, get_header_cpio, read_gz interface, rpm

    Jeff Angielski <jeff@theptrgroup.com>

        ftpput, ftpget

    Edward Betts <edward@debian.org>

        expr, hostid, logname, whoami

    John Beppu <beppu@codepoet.org>

        du, nslookup, sort

    Brian Candler <B.Candler@pobox.com>

        tiny-ls(ls)

    Randolph Chung <tausq@debian.org>

        fbset, ping, hostname

    Dave Cinege <dcinege@psychosis.com>

        more(v2), makedevs, dutmp, modularization, auto links file,
        various fixes, Linux Router Project maintenance

    Jordan Crouse <jordan@cosmicpenguin.net>

        ipcalc

    Magnus Damm <damm@opensource.se>

        tftp client insmod powerpc support

    Larry Doolittle <ldoolitt@recycle.lbl.gov>

        pristine source directory compilation, lots of patches and fixes.

    Glenn Engel <glenne@engel.org>

        httpd

    Gennady Feldman <gfeldman@gena01.com>

        Sysklogd (single threaded syslogd, IPC Circular buffer support,
        logread), various fixes.

    Karl M. Hegbloom <karlheg@debian.org>

        cp_mv.c, the test suite, various fixes to utility.c, &c.

    Daniel Jacobowitz <dan@debian.org>

        mktemp.c

    Matt Kraai <kraai@alumni.cmu.edu>

        documentation, bugfixes, test suite

    Stephan Linz <linz@li-pro.net>

        ipcalc, Red Hat equivalence

    John Lombardo <john@deltanet.com>

        tr

    Glenn McGrath <bug1@iinet.net.au>

        Common unarchiving code and unarchiving applets, ifupdown, ftpgetput,
        nameif, sed, patch, fold, install, uudecode.
        Various bugfixes, review and apply numerous patches.

    Manuel Novoa III <mjn3@codepoet.org>

        cat, head, mkfifo, mknod, rmdir, sleep, tee, tty, uniq, usleep, wc, yes,
        mesg, vconfig, make_directory, parse_mode, dirname, mode_string,
        get_last_path_component, simplify_path, and a number trivial libbb routines

        also bug fixes, partial rewrites, and size optimizations in
        ash, basename, cal, cmp, cp, df, du, echo, env, ln, logname, md5sum, mkdir,
        mv, realpath, rm, sort, tail, touch, uname, watch, arith, human_readable,
        interface, dutmp, ifconfig, route

    Vladimir Oleynik <dzo@simtreas.ru>

        cmdedit; xargs(current), httpd(current);
        ports: ash, crond, fdisk, inetd, stty, traceroute, top;
        locale, various fixes
        and irreconcilable critic of everything not perfect.

    Bruce Perens <bruce@pixar.com>

        Original author of BusyBox in 1995, 1996. Some of his code can
        still be found hiding here and there...

    Tim Riker <Tim@Rikers.org>

        bug fixes, member of fan club

    Kent Robotti <robotti@metconnect.com>

        reset, tons and tons of bug reports and patches.

    Chip Rosenthal <chip@unicom.com>, <crosenth@covad.com>

        wget - Contributed by permission of Covad Communications

    Pavel Roskin <proski@gnu.org>

        Lots of bugs fixes and patches.

    Gyepi Sam <gyepi@praxis-sw.com>

        Remote logging feature for syslogd

    Linus Torvalds <torvalds@transmeta.com>

        mkswap, fsck.minix, mkfs.minix

    Mark Whitley <markw@codepoet.org>

        grep, sed, cut, xargs(previous),
        style-guide, new-applet-HOWTO, bug fixes, etc.

    Charles P. Wright <cpwright@villagenet.com>

        gzip, mini-netcat(nc)

    Enrique Zanardi <ezanardi@ull.es>

        tarcat (since removed), loadkmap, various fixes, Debian maintenance

    Tito Ragusa <farmatito@tiscali.it>

        devfsd and size optimizations in strings, openvt and deallocvt.

    Paul Fox <pgf@foxharp.boston.ma.us>

        vi editing mode for ash, various other patches/fixes

    Roberto A. Foglietta <me@roberto.foglietta.name>

        port: dnsd

    Bernhard Reutner-Fischer <rep.dot.nop@gmail.com>

        misc

    Mike Frysinger <vapier@gentoo.org>

        initial e2fsprogs, printenv, setarch, sum, misc

    Jie Zhang <jie.zhang@analog.com>

        fixed two bugs in msh and hush (exitcode of killed processes)

